==> mozilla-source-0.9.9.tar.bz2: mozilla/editor/composer/src/nsEditorParserObserver.h <==
/* -*- Mode: C++; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* ***** BEGIN LICENSE BLOCK *****
 * Version: NPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Netscape Public License
 * Version 1.1 (the "License"); you may not use this file except in
 * compliance with the License. You may obtain a copy of the License at
 * http://www.mozilla.org/NPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is mozilla.org code.
 *
 * The Initial Developer of the Original Code is 
 * Netscape Communications Corporation.
 * Portions created by the Initial Developer are Copyright (C) 1998
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *   steve clark <buster@netscape.com>
 *
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the NPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the NPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

#include "nsIElementObserver.h"
#include "nsIObserver.h"
#include "nsIObserverService.h"

#include "nsWeakReference.h"
#include "nsString.h"
#include "nsVoidArray.h"
#include "nsHTMLTags.h"

class nsEditorParserObserver : public nsSupportsWeakReference,
                               public nsIElementObserver,
                               public nsIObserver
{
public:

                            nsEditorParserObserver();
  virtual                   ~nsEditorParserObserver();

  NS_DECL_ISUPPORTS

  /* method for nsIElementObserver */
  NS_IMETHOD                Notify(PRUint32 aDocumentID, eHTMLTags aTag, PRUint32 numOfAttributes, 
                                    const PRUnichar* nameArray[], const PRUnichar* valueArray[]);
  NS_IMETHOD                Notify(PRUint32 aDocumentID, const PRUnichar* aTag, PRUint32 numOfAttributes, 
                                    const PRUnichar* nameArray[], const PRUnichar* valueArray[]);
  NS_IMETHOD                Notify(nsISupports* aWebShell, 
                                   nsISupports* aChannel,
                                   const PRUnichar* aTag, 
                                   const nsStringArray* aKeys, 
                                   const nsStringArray* aValues);

  /* methods for nsIObserver */
  NS_DECL_NSIOBSERVER

  /* begin and end observing */
  NS_IMETHOD                Start(eHTMLTags* aWatchTags);
  NS_IMETHOD                End();

  /* query, did we find a bad tag? */
  NS_IMETHOD                GetBadTagFound(PRBool *aFound);

protected:

  virtual void              Notify();
  
protected:

  PRBool                    mBadTagFound;
};

==> mozilla-source-1.4.4.tar.bz2: mozilla/editor/composer/src/nsEditorParserObserver.h <==
/* -*- Mode: C++; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* ***** BEGIN LICENSE BLOCK *****
 * Version: NPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Netscape Public License
 * Version 1.1 (the "License"); you may not use this file except in
 * compliance with the License. You may obtain a copy of the License at
 * http://www.mozilla.org/NPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is mozilla.org code.
 *
 * The Initial Developer of the Original Code is 
 * Netscape Communications Corporation.
 * Portions created by the Initial Developer are Copyright (C) 1998
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *   steve clark <buster@netscape.com>
 *
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the NPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the NPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

#include "nsIElementObserver.h"
#include "nsIObserver.h"
#include "nsIObserverService.h"

#include "nsWeakReference.h"
#include "nsString.h"
#include "nsVoidArray.h"
#include "nsHTMLTags.h"

class nsEditorParserObserver : public nsSupportsWeakReference,
                               public nsIElementObserver,
                               public nsIObserver
{
public:

                            nsEditorParserObserver();
  virtual                   ~nsEditorParserObserver();

  NS_DECL_ISUPPORTS

  /* method for nsIElementObserver */
  NS_IMETHOD                Notify(PRUint32 aDocumentID, eHTMLTags aTag, PRUint32 numOfAttributes, 
                                    const PRUnichar* nameArray[], const PRUnichar* valueArray[]);
  NS_IMETHOD                Notify(PRUint32 aDocumentID, const PRUnichar* aTag, PRUint32 numOfAttributes, 
                                    const PRUnichar* nameArray[], const PRUnichar* valueArray[]);
  NS_IMETHOD                Notify(nsISupports* aWebShell, 
                                   nsISupports* aChannel,
                                   const PRUnichar* aTag, 
                                   const nsStringArray* aKeys, 
                                   const nsStringArray* aValues,
                                   const PRUint32 aFlags);

  /* methods for nsIObserver */
  NS_DECL_NSIOBSERVER

  /* begin and end observing */
  NS_IMETHOD                Start(eHTMLTags* aWatchTags);
  NS_IMETHOD                End();

  /* query, did we find a bad tag? */
  NS_IMETHOD                GetBadTagFound(PRBool *aFound);

protected:

  virtual void              Notify();
  
protected:

  PRBool                    mBadTagFound;
};
